==> haskell-hls-explicit-imports-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.1.0.0-AkXPiIGUvU02G49pzshkjm
key:                  hls-explicit-imports-plugin-2.1.0.0-AkXPiIGUvU02G49pzshkjm
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0e06b92730265fe0f529b70d5e972459
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.1.0.0-AkXPiIGUvU02G49pzshkjm

depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-9.6.6 ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-imports-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.1.0.0-KD1BPC2NZawJabOsvBooFU
key:                  hls-explicit-imports-plugin-2.1.0.0-KD1BPC2NZawJabOsvBooFU
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fe4ee8e1779b7f5f72132b7bc49e0380
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.1.0.0-KD1BPC2NZawJabOsvBooFU

depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-9.6.6 ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
